<?php

class Stripe_Express_Shortcodes
{
    function register_shortcode( $atts )
    {
        global  $wpdb ;
        if ( !isset( $atts['id'] ) ) {
            return '<div>stripe-express: id is required.</div>';
        }
        $id = sanitize_text_field( $atts['id'] );
        $presql = $wpdb->prepare( 'SELECT * FROM ' . $wpdb->prefix . 'stripe_express_elements WHERE id=%s ORDER BY id DESC LIMIT 0,1', $id );
        $config = $wpdb->get_row( $presql, ARRAY_A );
        if ( !$config ) {
            return '<div>[stripe-express ${id}/] not found id: ' . $id . '</div>';
        }
        // Fetch price detail from stripe
        $paymentConfig = $config['paymentConfig'];
        $uiConfig = ( isset( $atts['uiConfig'] ) ? $atts['uiConfig'] : $config['uiConfig'] );
        $apiKey = ( get_option( 'stripe_express_mode' ) == 'test' ? get_option( 'stripe_express_test_key' ) : get_option( 'stripe_express_live_key' ) );
        $objectConfig = array(
            'apiKey'        => $apiKey,
            'baseUrl'       => rest_url( IT_STRIPE_EXPRESS_REST_API . 'stripehook' ),
            'successUrl'    => esc_url_raw( get_option( 'stripe_express_success_url' ) ),
            'cancelUrl'     => esc_url_raw( get_option( 'stripe_express_cancel_url' ) ),
            'currency'      => get_option( 'stripe_express_currency' ),
            'language'      => get_option( 'stripe_express_language' ),
            'paymentConfig' => $paymentConfig,
            'uiConfig'      => $uiConfig,
        );
        // End getting
        $type = ( isset( $atts['type'] ) ? $atts['type'] : $config['type'] );
        $object_id = 'wp_stripe_express_object_' . uniqid();
        wp_enqueue_style( 'wp-stripe-express-elements' );
        wp_enqueue_script( 'wp-stripe-express-elements' );
        wp_localize_script( 'wp-stripe-express-elements', $object_id, $objectConfig );
        $theme = get_option( 'stripe_express_theme' );
        if ( !empty($theme) ) {
            wp_enqueue_style( 'wp-stripe-express-elements-theme' );
        }
        return '<div class="wp-stripe-express-shortcode" data-id="' . $object_id . '" data-type="' . $type . '"></div>';
    }

}